CCL: /home/chisarie/Documents/lsst_ccl/CCL/tests/ccl_test_params.c File Reference

CCL

Functions
ccl_test_params.c File Reference
`#include "ccl.h"`
`#include "ctest.h"`

## Functions
| CTEST_DATA (params)
| CTEST_SETUP (params)
| CTEST2 (params, create_lcdm)
| CTEST2 (params, create_wacdm)

## Function Documentation

## ◆ CTEST2() [1/2]

CTEST2 | ( | params | ,
|  | create_lcdm |
| ) |  |

## ◆ CTEST2() [2/2]

CTEST2 | ( | params | ,
|  | create_wacdm |
| ) |  |

## ◆ CTEST_DATA()

CTEST_DATA | ( | params |  | ) |

## ◆ CTEST_SETUP()

CTEST_SETUP | ( | params |  | ) |